# omni-belt

[![Unit-Tests](https://github.com/felixludos/omni-belt/actions/workflows/tests.yaml/badge.svg)](https://github.com/felixludos/omni-belt/actions/workflows/tests.yaml)


This is a simple tool belt containing pure python utilities for downstream projects.
